@@ -17,43 +17,19 @@ if not os.path.exists(assetsDir): # for pyinstaller pack
 
 defaultBaudrates = [9600, 19200, 38400, 57600, 74880, 115200, 921600, 1000000, 1500000, 2000000, 4500000]
 encodings = ["ASCII", "UTF-8", "UTF-16", "GBK", "GB2312", "GB18030"]
-customSendItemHeight = 60
+customSendItemHeight = 40
 
 author = "Neucrack"
 
 class Strings:
     def __init__(self, locale):
         set_locale(locale)
-        self.strBytes = _("bytes")
-        self.strSend = _("Send")
         self.strReceive = _("Receive")
-        self.strSerialPort = _("Port")
-        self.strSerialBaudrate = _("Baudrate")
-        self.strSerialBytes = _("DataBytes")
-        self.strSerialParity = _("Parity")
-        self.strSerialStopbits = _("Stopbits")
-        self.strAscii = _("ASCII")
-        self.strHex = _("HEX")
         self.strSendSettings = _("Send Settings")
         self.strReceiveSettings = _("Receive Settings")
-        self.strOpen = _("OPEN")
-        self.strClose = _("CLOSE")
-        self.strAutoLinefeed = _("Auto\nLinefeed\nms")
-        self.strScheduled = _("Timed Send\nms")
-        self.strSerialSettings = _("Serial Settings")
-        self.strSerialReceiveSettings = _("Receive Settings")
-        self.strSerialSendSettings = _("Send Settings")
-        self.strClearReceive = _("ClearReceive")
-        self.strAdd = _("+")
         self.strFunctionalSend = _("Functional Send")
-        self.strSendFile = _("Send File")
-        self.strSendingFile = _("Sendding File")
-        self.strOpenFailed = _("Open Failed")
         self.strClosed = _("Closed")
-        self.strWriteError = _("Send Error")
         self.strReady = _("Ready")
-        self.strCRLF = _("<CRLF>")
-        self.strTimeFormatError = _("Time format error")
         self.strHelp = _("HELP")
         self.strAbout = _("ABOUT")
         self.strSettings = _("Settings")
@@ -85,33 +61,30 @@ else:
     else:
         configFilePath = get_config_path(configFileName)
 
+print("-- config path:", configFilePath)
+
 
 class Parameters:
-    baudRate = 4
-    dataBytes = 3
-    parity = 0
-    stopBits = 0
-    receiveAscii = True
-    receiveAutoLinefeed = False
-    receiveAutoLindefeedTime = 200
-    sendAscii = True
-    sendScheduled = False
-    sendScheduledTime = 300
-    useCRLF = True
-    skin = 2
-    rts  = 0
-    dtr  = 0
-    locale = "en"
-    showTimestamp = False
-    recordSend = False
-    encoding = "ASCII"
-    saveLogPath = ""
-    saveLog = False
-    color = False
-    sendEscape = False
-    skipVersion = None
-    customSendItems = []
-    sendHistoryList = []
+    basic = {
+        "skin": "light",
+        "locale": "en",
+        "encoding": "ASCII",
+        "skipVersion": None,
+        "connId": "serial",
+        "plugins": [],          # enabled plugins ID
+        "activePlugin": "dbg" 
+    }
+    conns = {
+        # "serial": {
+        # },
+        # "tcpudp": {
+        # }
+    }
+    plugins = {
+        # "dbg": {
+        # },
+    }
+
 
     def save(self, path):
         path = os.path.abspath(path)
@@ -126,15 +99,19 @@ class Parameters:
         if not os.path.exists(os.path.dirname(path)):
             os.makedirs(os.path.dirname(path))
         with open(path, "w", encoding="utf-8") as f:
-            json.dump(obj, f, indent=4)
+            json.dump(obj, f, indent=4, ensure_ascii=False)
 
     def load(self, path):
         if not os.path.exists(path):
             return
         with open(path, encoding="utf-8") as f:
             obj = json.load(f)
-        for key in obj:
-            self.__setattr__(key, obj[key])
+        if "basic" in obj:
+            self.basic.update(obj["basic"])
+        if "conns" in obj:
+            self.conns.update(obj["conns"])
+        if "plugins" in obj:
+            self.plugins.update(obj["plugins"])
         
 
 strStyleShowHideButtonLeft = '''
